# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .build_pipeline_stage_run_progress import BuildPipelineStageRunProgress
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BuildStageRunProgress(BuildPipelineStageRunProgress):
    """
    Specifies the run details for Build stage.
    """

    #: A constant which can be used with the image property of a BuildStageRunProgress.
    #: This constant has a value of "OL7_X86_64_STANDARD_10"
    IMAGE_OL7_X86_64_STANDARD_10 = "OL7_X86_64_STANDARD_10"

    def __init__(self, **kwargs):
        """
        Initializes a new BuildStageRunProgress object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.BuildStageRunProgress.build_pipeline_stage_type` attribute
        of this class is ``BUILD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param stage_display_name:
            The value to assign to the stage_display_name property of this BuildStageRunProgress.
        :type stage_display_name: str

        :param build_pipeline_stage_type:
            The value to assign to the build_pipeline_stage_type property of this BuildStageRunProgress.
        :type build_pipeline_stage_type: str

        :param build_pipeline_stage_id:
            The value to assign to the build_pipeline_stage_id property of this BuildStageRunProgress.
        :type build_pipeline_stage_id: str

        :param time_started:
            The value to assign to the time_started property of this BuildStageRunProgress.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this BuildStageRunProgress.
        :type time_finished: datetime

        :param status:
            The value to assign to the status property of this BuildStageRunProgress.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "FAILED", "SUCCEEDED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param build_pipeline_stage_predecessors:
            The value to assign to the build_pipeline_stage_predecessors property of this BuildStageRunProgress.
        :type build_pipeline_stage_predecessors: oci.devops.models.BuildPipelineStagePredecessorCollection

        :param actual_build_runner_shape:
            The value to assign to the actual_build_runner_shape property of this BuildStageRunProgress.
        :type actual_build_runner_shape: str

        :param actual_build_runner_shape_config:
            The value to assign to the actual_build_runner_shape_config property of this BuildStageRunProgress.
        :type actual_build_runner_shape_config: oci.devops.models.ActualBuildRunnerShapeConfig

        :param image:
            The value to assign to the image property of this BuildStageRunProgress.
            Allowed values for this property are: "OL7_X86_64_STANDARD_10", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type image: str

        :param build_spec_file:
            The value to assign to the build_spec_file property of this BuildStageRunProgress.
        :type build_spec_file: str

        :param stage_execution_timeout_in_seconds:
            The value to assign to the stage_execution_timeout_in_seconds property of this BuildStageRunProgress.
        :type stage_execution_timeout_in_seconds: int

        :param build_source_collection:
            The value to assign to the build_source_collection property of this BuildStageRunProgress.
        :type build_source_collection: oci.devops.models.BuildSourceCollection

        :param primary_build_source:
            The value to assign to the primary_build_source property of this BuildStageRunProgress.
        :type primary_build_source: str

        :param steps:
            The value to assign to the steps property of this BuildStageRunProgress.
        :type steps: list[oci.devops.models.BuildStageRunStep]

        :param exported_variables:
            The value to assign to the exported_variables property of this BuildStageRunProgress.
        :type exported_variables: oci.devops.models.ExportedVariableCollection

        """
        self.swagger_types = {
            'stage_display_name': 'str',
            'build_pipeline_stage_type': 'str',
            'build_pipeline_stage_id': 'str',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'status': 'str',
            'build_pipeline_stage_predecessors': 'BuildPipelineStagePredecessorCollection',
            'actual_build_runner_shape': 'str',
            'actual_build_runner_shape_config': 'ActualBuildRunnerShapeConfig',
            'image': 'str',
            'build_spec_file': 'str',
            'stage_execution_timeout_in_seconds': 'int',
            'build_source_collection': 'BuildSourceCollection',
            'primary_build_source': 'str',
            'steps': 'list[BuildStageRunStep]',
            'exported_variables': 'ExportedVariableCollection'
        }

        self.attribute_map = {
            'stage_display_name': 'stageDisplayName',
            'build_pipeline_stage_type': 'buildPipelineStageType',
            'build_pipeline_stage_id': 'buildPipelineStageId',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'status': 'status',
            'build_pipeline_stage_predecessors': 'buildPipelineStagePredecessors',
            'actual_build_runner_shape': 'actualBuildRunnerShape',
            'actual_build_runner_shape_config': 'actualBuildRunnerShapeConfig',
            'image': 'image',
            'build_spec_file': 'buildSpecFile',
            'stage_execution_timeout_in_seconds': 'stageExecutionTimeoutInSeconds',
            'build_source_collection': 'buildSourceCollection',
            'primary_build_source': 'primaryBuildSource',
            'steps': 'steps',
            'exported_variables': 'exportedVariables'
        }

        self._stage_display_name = None
        self._build_pipeline_stage_type = None
        self._build_pipeline_stage_id = None
        self._time_started = None
        self._time_finished = None
        self._status = None
        self._build_pipeline_stage_predecessors = None
        self._actual_build_runner_shape = None
        self._actual_build_runner_shape_config = None
        self._image = None
        self._build_spec_file = None
        self._stage_execution_timeout_in_seconds = None
        self._build_source_collection = None
        self._primary_build_source = None
        self._steps = None
        self._exported_variables = None
        self._build_pipeline_stage_type = 'BUILD'

    @property
    def actual_build_runner_shape(self):
        """
        Gets the actual_build_runner_shape of this BuildStageRunProgress.
        Name of Build Runner shape where this Build Stage is running.


        :return: The actual_build_runner_shape of this BuildStageRunProgress.
        :rtype: str
        """
        return self._actual_build_runner_shape

    @actual_build_runner_shape.setter
    def actual_build_runner_shape(self, actual_build_runner_shape):
        """
        Sets the actual_build_runner_shape of this BuildStageRunProgress.
        Name of Build Runner shape where this Build Stage is running.


        :param actual_build_runner_shape: The actual_build_runner_shape of this BuildStageRunProgress.
        :type: str
        """
        self._actual_build_runner_shape = actual_build_runner_shape

    @property
    def actual_build_runner_shape_config(self):
        """
        Gets the actual_build_runner_shape_config of this BuildStageRunProgress.

        :return: The actual_build_runner_shape_config of this BuildStageRunProgress.
        :rtype: oci.devops.models.ActualBuildRunnerShapeConfig
        """
        return self._actual_build_runner_shape_config

    @actual_build_runner_shape_config.setter
    def actual_build_runner_shape_config(self, actual_build_runner_shape_config):
        """
        Sets the actual_build_runner_shape_config of this BuildStageRunProgress.

        :param actual_build_runner_shape_config: The actual_build_runner_shape_config of this BuildStageRunProgress.
        :type: oci.devops.models.ActualBuildRunnerShapeConfig
        """
        self._actual_build_runner_shape_config = actual_build_runner_shape_config

    @property
    def image(self):
        """
        **[Required]** Gets the image of this BuildStageRunProgress.
        Image name for the Build Environment

        Allowed values for this property are: "OL7_X86_64_STANDARD_10", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The image of this BuildStageRunProgress.
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """
        Sets the image of this BuildStageRunProgress.
        Image name for the Build Environment


        :param image: The image of this BuildStageRunProgress.
        :type: str
        """
        allowed_values = ["OL7_X86_64_STANDARD_10"]
        if not value_allowed_none_or_none_sentinel(image, allowed_values):
            image = 'UNKNOWN_ENUM_VALUE'
        self._image = image

    @property
    def build_spec_file(self):
        """
        Gets the build_spec_file of this BuildStageRunProgress.
        The path to the build specification file for this Environment. The default location if not specified is build_spec.yaml


        :return: The build_spec_file of this BuildStageRunProgress.
        :rtype: str
        """
        return self._build_spec_file

    @build_spec_file.setter
    def build_spec_file(self, build_spec_file):
        """
        Sets the build_spec_file of this BuildStageRunProgress.
        The path to the build specification file for this Environment. The default location if not specified is build_spec.yaml


        :param build_spec_file: The build_spec_file of this BuildStageRunProgress.
        :type: str
        """
        self._build_spec_file = build_spec_file

    @property
    def stage_execution_timeout_in_seconds(self):
        """
        Gets the stage_execution_timeout_in_seconds of this BuildStageRunProgress.
        Timeout for the Build Stage Execution. Value in seconds.


        :return: The stage_execution_timeout_in_seconds of this BuildStageRunProgress.
        :rtype: int
        """
        return self._stage_execution_timeout_in_seconds

    @stage_execution_timeout_in_seconds.setter
    def stage_execution_timeout_in_seconds(self, stage_execution_timeout_in_seconds):
        """
        Sets the stage_execution_timeout_in_seconds of this BuildStageRunProgress.
        Timeout for the Build Stage Execution. Value in seconds.


        :param stage_execution_timeout_in_seconds: The stage_execution_timeout_in_seconds of this BuildStageRunProgress.
        :type: int
        """
        self._stage_execution_timeout_in_seconds = stage_execution_timeout_in_seconds

    @property
    def build_source_collection(self):
        """
        **[Required]** Gets the build_source_collection of this BuildStageRunProgress.

        :return: The build_source_collection of this BuildStageRunProgress.
        :rtype: oci.devops.models.BuildSourceCollection
        """
        return self._build_source_collection

    @build_source_collection.setter
    def build_source_collection(self, build_source_collection):
        """
        Sets the build_source_collection of this BuildStageRunProgress.

        :param build_source_collection: The build_source_collection of this BuildStageRunProgress.
        :type: oci.devops.models.BuildSourceCollection
        """
        self._build_source_collection = build_source_collection

    @property
    def primary_build_source(self):
        """
        Gets the primary_build_source of this BuildStageRunProgress.
        Name of the BuildSource in which the build_spec.yml file need to be located. If not specified, the 1st entry in the BuildSource collection will be chosen as Primary.


        :return: The primary_build_source of this BuildStageRunProgress.
        :rtype: str
        """
        return self._primary_build_source

    @primary_build_source.setter
    def primary_build_source(self, primary_build_source):
        """
        Sets the primary_build_source of this BuildStageRunProgress.
        Name of the BuildSource in which the build_spec.yml file need to be located. If not specified, the 1st entry in the BuildSource collection will be chosen as Primary.


        :param primary_build_source: The primary_build_source of this BuildStageRunProgress.
        :type: str
        """
        self._primary_build_source = primary_build_source

    @property
    def steps(self):
        """
        Gets the steps of this BuildStageRunProgress.
        The details about all the steps in a Build stage


        :return: The steps of this BuildStageRunProgress.
        :rtype: list[oci.devops.models.BuildStageRunStep]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """
        Sets the steps of this BuildStageRunProgress.
        The details about all the steps in a Build stage


        :param steps: The steps of this BuildStageRunProgress.
        :type: list[oci.devops.models.BuildStageRunStep]
        """
        self._steps = steps

    @property
    def exported_variables(self):
        """
        Gets the exported_variables of this BuildStageRunProgress.

        :return: The exported_variables of this BuildStageRunProgress.
        :rtype: oci.devops.models.ExportedVariableCollection
        """
        return self._exported_variables

    @exported_variables.setter
    def exported_variables(self, exported_variables):
        """
        Sets the exported_variables of this BuildStageRunProgress.

        :param exported_variables: The exported_variables of this BuildStageRunProgress.
        :type: oci.devops.models.ExportedVariableCollection
        """
        self._exported_variables = exported_variables

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataTypeStat(object):
    """
    Statistical data in profiling results
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataTypeStat object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param value:
            The value to assign to the value property of this DataTypeStat.
        :type value: str

        :param confidence:
            The value to assign to the confidence property of this DataTypeStat.
        :type confidence: int

        :param freq:
            The value to assign to the freq property of this DataTypeStat.
        :type freq: int

        :param freq_percentage:
            The value to assign to the freq_percentage property of this DataTypeStat.
        :type freq_percentage: float

        """
        self.swagger_types = {
            'value': 'str',
            'confidence': 'int',
            'freq': 'int',
            'freq_percentage': 'float'
        }

        self.attribute_map = {
            'value': 'value',
            'confidence': 'confidence',
            'freq': 'freq',
            'freq_percentage': 'freqPercentage'
        }

        self._value = None
        self._confidence = None
        self._freq = None
        self._freq_percentage = None

    @property
    def value(self):
        """
        Gets the value of this DataTypeStat.
        Value of the confidence of the profile result


        :return: The value of this DataTypeStat.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this DataTypeStat.
        Value of the confidence of the profile result


        :param value: The value of this DataTypeStat.
        :type: str
        """
        self._value = value

    @property
    def confidence(self):
        """
        Gets the confidence of this DataTypeStat.
        Placeholder for now, in future we will return the confidence of the profile result (because we are using sampled data and not whole data)


        :return: The confidence of this DataTypeStat.
        :rtype: int
        """
        return self._confidence

    @confidence.setter
    def confidence(self, confidence):
        """
        Sets the confidence of this DataTypeStat.
        Placeholder for now, in future we will return the confidence of the profile result (because we are using sampled data and not whole data)


        :param confidence: The confidence of this DataTypeStat.
        :type: int
        """
        self._confidence = confidence

    @property
    def freq(self):
        """
        Gets the freq of this DataTypeStat.
        How many times that value occurred.


        :return: The freq of this DataTypeStat.
        :rtype: int
        """
        return self._freq

    @freq.setter
    def freq(self, freq):
        """
        Sets the freq of this DataTypeStat.
        How many times that value occurred.


        :param freq: The freq of this DataTypeStat.
        :type: int
        """
        self._freq = freq

    @property
    def freq_percentage(self):
        """
        Gets the freq_percentage of this DataTypeStat.
        Frequency percentage across the sampled row counts (excluding nulls).


        :return: The freq_percentage of this DataTypeStat.
        :rtype: float
        """
        return self._freq_percentage

    @freq_percentage.setter
    def freq_percentage(self, freq_percentage):
        """
        Sets the freq_percentage of this DataTypeStat.
        Frequency percentage across the sampled row counts (excluding nulls).


        :param freq_percentage: The freq_percentage of this DataTypeStat.
        :type: float
        """
        self._freq_percentage = freq_percentage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ServiceEnvironment(object):
    """
    Detailed information about a service environment.

    **Note:** Service URL formats may vary from the provided example.
    """

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "INITIALIZED"
    STATUS_INITIALIZED = "INITIALIZED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_ACTIVATION"
    STATUS_BEGIN_ACTIVATION = "BEGIN_ACTIVATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "ACTIVE"
    STATUS_ACTIVE = "ACTIVE"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_SOFT_TERMINATION"
    STATUS_BEGIN_SOFT_TERMINATION = "BEGIN_SOFT_TERMINATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "SOFT_TERMINATED"
    STATUS_SOFT_TERMINATED = "SOFT_TERMINATED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_TERMINATION"
    STATUS_BEGIN_TERMINATION = "BEGIN_TERMINATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "CANCELED"
    STATUS_CANCELED = "CANCELED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "TERMINATED"
    STATUS_TERMINATED = "TERMINATED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_DISABLING"
    STATUS_BEGIN_DISABLING = "BEGIN_DISABLING"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_ENABLING"
    STATUS_BEGIN_ENABLING = "BEGIN_ENABLING"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_MIGRATION"
    STATUS_BEGIN_MIGRATION = "BEGIN_MIGRATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "DISABLED"
    STATUS_DISABLED = "DISABLED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_SUSPENSION"
    STATUS_BEGIN_SUSPENSION = "BEGIN_SUSPENSION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_RESUMPTION"
    STATUS_BEGIN_RESUMPTION = "BEGIN_RESUMPTION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "SUSPENDED"
    STATUS_SUSPENDED = "SUSPENDED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_LOCK_RELOCATION"
    STATUS_BEGIN_LOCK_RELOCATION = "BEGIN_LOCK_RELOCATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "LOCKED_RELOCATION"
    STATUS_LOCKED_RELOCATION = "LOCKED_RELOCATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_RELOCATION"
    STATUS_BEGIN_RELOCATION = "BEGIN_RELOCATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "RELOCATED"
    STATUS_RELOCATED = "RELOCATED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_UNLOCK_RELOCATION"
    STATUS_BEGIN_UNLOCK_RELOCATION = "BEGIN_UNLOCK_RELOCATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "UNLOCKED_RELOCATION"
    STATUS_UNLOCKED_RELOCATION = "UNLOCKED_RELOCATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "FAILED_LOCK_RELOCATION"
    STATUS_FAILED_LOCK_RELOCATION = "FAILED_LOCK_RELOCATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "FAILED_ACTIVATION"
    STATUS_FAILED_ACTIVATION = "FAILED_ACTIVATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "FAILED_MIGRATION"
    STATUS_FAILED_MIGRATION = "FAILED_MIGRATION"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "ACCESS_DISABLED"
    STATUS_ACCESS_DISABLED = "ACCESS_DISABLED"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_DISABLING_ACCESS"
    STATUS_BEGIN_DISABLING_ACCESS = "BEGIN_DISABLING_ACCESS"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "BEGIN_ENABLING_ACCESS"
    STATUS_BEGIN_ENABLING_ACCESS = "BEGIN_ENABLING_ACCESS"

    #: A constant which can be used with the status property of a ServiceEnvironment.
    #: This constant has a value of "TRA_UNKNOWN"
    STATUS_TRA_UNKNOWN = "TRA_UNKNOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new ServiceEnvironment object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ServiceEnvironment.
        :type id: str

        :param subscription_id:
            The value to assign to the subscription_id property of this ServiceEnvironment.
        :type subscription_id: str

        :param status:
            The value to assign to the status property of this ServiceEnvironment.
            Allowed values for this property are: "INITIALIZED", "BEGIN_ACTIVATION", "ACTIVE", "BEGIN_SOFT_TERMINATION", "SOFT_TERMINATED", "BEGIN_TERMINATION", "CANCELED", "TERMINATED", "BEGIN_DISABLING", "BEGIN_ENABLING", "BEGIN_MIGRATION", "DISABLED", "BEGIN_SUSPENSION", "BEGIN_RESUMPTION", "SUSPENDED", "BEGIN_LOCK_RELOCATION", "LOCKED_RELOCATION", "BEGIN_RELOCATION", "RELOCATED", "BEGIN_UNLOCK_RELOCATION", "UNLOCKED_RELOCATION", "FAILED_LOCK_RELOCATION", "FAILED_ACTIVATION", "FAILED_MIGRATION", "ACCESS_DISABLED", "BEGIN_DISABLING_ACCESS", "BEGIN_ENABLING_ACCESS", "TRA_UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ServiceEnvironment.
        :type compartment_id: str

        :param service_definition:
            The value to assign to the service_definition property of this ServiceEnvironment.
        :type service_definition: oci.service_manager_proxy.models.ServiceDefinition

        :param console_url:
            The value to assign to the console_url property of this ServiceEnvironment.
        :type console_url: str

        :param service_environment_endpoints:
            The value to assign to the service_environment_endpoints property of this ServiceEnvironment.
        :type service_environment_endpoints: list[oci.service_manager_proxy.models.ServiceEnvironmentEndPointOverview]

        """
        self.swagger_types = {
            'id': 'str',
            'subscription_id': 'str',
            'status': 'str',
            'compartment_id': 'str',
            'service_definition': 'ServiceDefinition',
            'console_url': 'str',
            'service_environment_endpoints': 'list[ServiceEnvironmentEndPointOverview]'
        }

        self.attribute_map = {
            'id': 'id',
            'subscription_id': 'subscriptionId',
            'status': 'status',
            'compartment_id': 'compartmentId',
            'service_definition': 'serviceDefinition',
            'console_url': 'consoleUrl',
            'service_environment_endpoints': 'serviceEnvironmentEndpoints'
        }

        self._id = None
        self._subscription_id = None
        self._status = None
        self._compartment_id = None
        self._service_definition = None
        self._console_url = None
        self._service_environment_endpoints = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ServiceEnvironment.
        Unqiue identifier for the entitlement related to the environment.

        **Note:** Not an `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this ServiceEnvironment.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ServiceEnvironment.
        Unqiue identifier for the entitlement related to the environment.

        **Note:** Not an `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this ServiceEnvironment.
        :type: str
        """
        self._id = id

    @property
    def subscription_id(self):
        """
        **[Required]** Gets the subscription_id of this ServiceEnvironment.
        The unique subscription ID associated with the service environment ID.

        **Note:** Not an `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subscription_id of this ServiceEnvironment.
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """
        Sets the subscription_id of this ServiceEnvironment.
        The unique subscription ID associated with the service environment ID.

        **Note:** Not an `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subscription_id: The subscription_id of this ServiceEnvironment.
        :type: str
        """
        self._subscription_id = subscription_id

    @property
    def status(self):
        """
        **[Required]** Gets the status of this ServiceEnvironment.
        Status of the entitlement registration for the service.

        Allowed values for this property are: "INITIALIZED", "BEGIN_ACTIVATION", "ACTIVE", "BEGIN_SOFT_TERMINATION", "SOFT_TERMINATED", "BEGIN_TERMINATION", "CANCELED", "TERMINATED", "BEGIN_DISABLING", "BEGIN_ENABLING", "BEGIN_MIGRATION", "DISABLED", "BEGIN_SUSPENSION", "BEGIN_RESUMPTION", "SUSPENDED", "BEGIN_LOCK_RELOCATION", "LOCKED_RELOCATION", "BEGIN_RELOCATION", "RELOCATED", "BEGIN_UNLOCK_RELOCATION", "UNLOCKED_RELOCATION", "FAILED_LOCK_RELOCATION", "FAILED_ACTIVATION", "FAILED_MIGRATION", "ACCESS_DISABLED", "BEGIN_DISABLING_ACCESS", "BEGIN_ENABLING_ACCESS", "TRA_UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ServiceEnvironment.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ServiceEnvironment.
        Status of the entitlement registration for the service.


        :param status: The status of this ServiceEnvironment.
        :type: str
        """
        allowed_values = ["INITIALIZED", "BEGIN_ACTIVATION", "ACTIVE", "BEGIN_SOFT_TERMINATION", "SOFT_TERMINATED", "BEGIN_TERMINATION", "CANCELED", "TERMINATED", "BEGIN_DISABLING", "BEGIN_ENABLING", "BEGIN_MIGRATION", "DISABLED", "BEGIN_SUSPENSION", "BEGIN_RESUMPTION", "SUSPENDED", "BEGIN_LOCK_RELOCATION", "LOCKED_RELOCATION", "BEGIN_RELOCATION", "RELOCATED", "BEGIN_UNLOCK_RELOCATION", "UNLOCKED_RELOCATION", "FAILED_LOCK_RELOCATION", "FAILED_ACTIVATION", "FAILED_MIGRATION", "ACCESS_DISABLED", "BEGIN_DISABLING_ACCESS", "BEGIN_ENABLING_ACCESS", "TRA_UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ServiceEnvironment.
        The `OCID`__ for the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ServiceEnvironment.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ServiceEnvironment.
        The `OCID`__ for the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ServiceEnvironment.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def service_definition(self):
        """
        **[Required]** Gets the service_definition of this ServiceEnvironment.

        :return: The service_definition of this ServiceEnvironment.
        :rtype: oci.service_manager_proxy.models.ServiceDefinition
        """
        return self._service_definition

    @service_definition.setter
    def service_definition(self, service_definition):
        """
        Sets the service_definition of this ServiceEnvironment.

        :param service_definition: The service_definition of this ServiceEnvironment.
        :type: oci.service_manager_proxy.models.ServiceDefinition
        """
        self._service_definition = service_definition

    @property
    def console_url(self):
        """
        Gets the console_url of this ServiceEnvironment.
        The URL for the console.


        :return: The console_url of this ServiceEnvironment.
        :rtype: str
        """
        return self._console_url

    @console_url.setter
    def console_url(self, console_url):
        """
        Sets the console_url of this ServiceEnvironment.
        The URL for the console.


        :param console_url: The console_url of this ServiceEnvironment.
        :type: str
        """
        self._console_url = console_url

    @property
    def service_environment_endpoints(self):
        """
        Gets the service_environment_endpoints of this ServiceEnvironment.
        Array of service environment end points.


        :return: The service_environment_endpoints of this ServiceEnvironment.
        :rtype: list[oci.service_manager_proxy.models.ServiceEnvironmentEndPointOverview]
        """
        return self._service_environment_endpoints

    @service_environment_endpoints.setter
    def service_environment_endpoints(self, service_environment_endpoints):
        """
        Sets the service_environment_endpoints of this ServiceEnvironment.
        Array of service environment end points.


        :param service_environment_endpoints: The service_environment_endpoints of this ServiceEnvironment.
        :type: list[oci.service_manager_proxy.models.ServiceEnvironmentEndPointOverview]
        """
        self._service_environment_endpoints = service_environment_endpoints

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SecurityRule(object):
    """
    Security Rule used in the firewall policy rules.
    Security Rules determine whether to block or allow a session based on traffic attributes,
    such as  the source and destination IP address, protocol/port, and the HTTP(S) target URL.
    """

    #: A constant which can be used with the action property of a SecurityRule.
    #: This constant has a value of "ALLOW"
    ACTION_ALLOW = "ALLOW"

    #: A constant which can be used with the action property of a SecurityRule.
    #: This constant has a value of "DROP"
    ACTION_DROP = "DROP"

    #: A constant which can be used with the action property of a SecurityRule.
    #: This constant has a value of "REJECT"
    ACTION_REJECT = "REJECT"

    #: A constant which can be used with the action property of a SecurityRule.
    #: This constant has a value of "INSPECT"
    ACTION_INSPECT = "INSPECT"

    #: A constant which can be used with the inspection property of a SecurityRule.
    #: This constant has a value of "INTRUSION_DETECTION"
    INSPECTION_INTRUSION_DETECTION = "INTRUSION_DETECTION"

    #: A constant which can be used with the inspection property of a SecurityRule.
    #: This constant has a value of "INTRUSION_PREVENTION"
    INSPECTION_INTRUSION_PREVENTION = "INTRUSION_PREVENTION"

    def __init__(self, **kwargs):
        """
        Initializes a new SecurityRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SecurityRule.
        :type name: str

        :param condition:
            The value to assign to the condition property of this SecurityRule.
        :type condition: oci.network_firewall.models.SecurityRuleMatchCriteria

        :param action:
            The value to assign to the action property of this SecurityRule.
            Allowed values for this property are: "ALLOW", "DROP", "REJECT", "INSPECT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type action: str

        :param inspection:
            The value to assign to the inspection property of this SecurityRule.
            Allowed values for this property are: "INTRUSION_DETECTION", "INTRUSION_PREVENTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type inspection: str

        """
        self.swagger_types = {
            'name': 'str',
            'condition': 'SecurityRuleMatchCriteria',
            'action': 'str',
            'inspection': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'condition': 'condition',
            'action': 'action',
            'inspection': 'inspection'
        }

        self._name = None
        self._condition = None
        self._action = None
        self._inspection = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this SecurityRule.
        Name for the Security rule, must be unique within the policy.


        :return: The name of this SecurityRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SecurityRule.
        Name for the Security rule, must be unique within the policy.


        :param name: The name of this SecurityRule.
        :type: str
        """
        self._name = name

    @property
    def condition(self):
        """
        **[Required]** Gets the condition of this SecurityRule.

        :return: The condition of this SecurityRule.
        :rtype: oci.network_firewall.models.SecurityRuleMatchCriteria
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this SecurityRule.

        :param condition: The condition of this SecurityRule.
        :type: oci.network_firewall.models.SecurityRuleMatchCriteria
        """
        self._condition = condition

    @property
    def action(self):
        """
        **[Required]** Gets the action of this SecurityRule.
        Types of Action on the Traffic flow.

          * ALLOW - Allows the traffic.
          * DROP - Silently drops the traffic, e.g. without sending a TCP reset.
          * REJECT - Rejects the traffic, sending a TCP reset to client and/or server as applicable.
          * INSPECT - Inspects traffic for vulnerability as specified in `inspection`, which may result in rejection.

        Allowed values for this property are: "ALLOW", "DROP", "REJECT", "INSPECT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The action of this SecurityRule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this SecurityRule.
        Types of Action on the Traffic flow.

          * ALLOW - Allows the traffic.
          * DROP - Silently drops the traffic, e.g. without sending a TCP reset.
          * REJECT - Rejects the traffic, sending a TCP reset to client and/or server as applicable.
          * INSPECT - Inspects traffic for vulnerability as specified in `inspection`, which may result in rejection.


        :param action: The action of this SecurityRule.
        :type: str
        """
        allowed_values = ["ALLOW", "DROP", "REJECT", "INSPECT"]
        if not value_allowed_none_or_none_sentinel(action, allowed_values):
            action = 'UNKNOWN_ENUM_VALUE'
        self._action = action

    @property
    def inspection(self):
        """
        Gets the inspection of this SecurityRule.
        Type of inspection to affect the Traffic flow. This is only applicable if action is INSPECT.

          * INTRUSION_DETECTION - Intrusion Detection.
          * INTRUSION_PREVENTION - Intrusion Detection and Prevention. Traffic classified as potentially malicious will be rejected as described in `type`.

        Allowed values for this property are: "INTRUSION_DETECTION", "INTRUSION_PREVENTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The inspection of this SecurityRule.
        :rtype: str
        """
        return self._inspection

    @inspection.setter
    def inspection(self, inspection):
        """
        Sets the inspection of this SecurityRule.
        Type of inspection to affect the Traffic flow. This is only applicable if action is INSPECT.

          * INTRUSION_DETECTION - Intrusion Detection.
          * INTRUSION_PREVENTION - Intrusion Detection and Prevention. Traffic classified as potentially malicious will be rejected as described in `type`.


        :param inspection: The inspection of this SecurityRule.
        :type: str
        """
        allowed_values = ["INTRUSION_DETECTION", "INTRUSION_PREVENTION"]
        if not value_allowed_none_or_none_sentinel(inspection, allowed_values):
            inspection = 'UNKNOWN_ENUM_VALUE'
        self._inspection = inspection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AccessibleCompartmentResponse(object):
    """
    AccessibleCompartmentResponse model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AccessibleCompartmentResponse object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartments_metadata:
            The value to assign to the compartments_metadata property of this AccessibleCompartmentResponse.
        :type compartments_metadata: list[oci.identity_data_plane.models.CompartmentMetadata]

        """
        self.swagger_types = {
            'compartments_metadata': 'list[CompartmentMetadata]'
        }

        self.attribute_map = {
            'compartments_metadata': 'compartmentsMetadata'
        }

        self._compartments_metadata = None

    @property
    def compartments_metadata(self):
        """
        **[Required]** Gets the compartments_metadata of this AccessibleCompartmentResponse.
        The compartments metadata.


        :return: The compartments_metadata of this AccessibleCompartmentResponse.
        :rtype: list[oci.identity_data_plane.models.CompartmentMetadata]
        """
        return self._compartments_metadata

    @compartments_metadata.setter
    def compartments_metadata(self, compartments_metadata):
        """
        Sets the compartments_metadata of this AccessibleCompartmentResponse.
        The compartments metadata.


        :param compartments_metadata: The compartments_metadata of this AccessibleCompartmentResponse.
        :type: list[oci.identity_data_plane.models.CompartmentMetadata]
        """
        self._compartments_metadata = compartments_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateProfileDetails(object):
    """
    Details for creating a profile.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateProfileDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateProfileDetails.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this CreateProfileDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateProfileDetails.
        :type description: str

        :param aggregation_interval_in_days:
            The value to assign to the aggregation_interval_in_days property of this CreateProfileDetails.
        :type aggregation_interval_in_days: int

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateProfileDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateProfileDetails.
        :type freeform_tags: dict(str, str)

        :param levels_configuration:
            The value to assign to the levels_configuration property of this CreateProfileDetails.
        :type levels_configuration: oci.optimizer.models.LevelsConfiguration

        :param target_compartments:
            The value to assign to the target_compartments property of this CreateProfileDetails.
        :type target_compartments: oci.optimizer.models.TargetCompartments

        :param target_tags:
            The value to assign to the target_tags property of this CreateProfileDetails.
        :type target_tags: oci.optimizer.models.TargetTags

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'name': 'str',
            'description': 'str',
            'aggregation_interval_in_days': 'int',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'levels_configuration': 'LevelsConfiguration',
            'target_compartments': 'TargetCompartments',
            'target_tags': 'TargetTags'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'name': 'name',
            'description': 'description',
            'aggregation_interval_in_days': 'aggregationIntervalInDays',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'levels_configuration': 'levelsConfiguration',
            'target_compartments': 'targetCompartments',
            'target_tags': 'targetTags'
        }

        self._compartment_id = None
        self._name = None
        self._description = None
        self._aggregation_interval_in_days = None
        self._defined_tags = None
        self._freeform_tags = None
        self._levels_configuration = None
        self._target_compartments = None
        self._target_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateProfileDetails.
        The OCID of the tenancy. The tenancy is the root compartment.


        :return: The compartment_id of this CreateProfileDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateProfileDetails.
        The OCID of the tenancy. The tenancy is the root compartment.


        :param compartment_id: The compartment_id of this CreateProfileDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateProfileDetails.
        The name assigned to the profile. Avoid entering confidential information.


        :return: The name of this CreateProfileDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateProfileDetails.
        The name assigned to the profile. Avoid entering confidential information.


        :param name: The name of this CreateProfileDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        **[Required]** Gets the description of this CreateProfileDetails.
        Text describing the profile. Avoid entering confidential information.


        :return: The description of this CreateProfileDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateProfileDetails.
        Text describing the profile. Avoid entering confidential information.


        :param description: The description of this CreateProfileDetails.
        :type: str
        """
        self._description = description

    @property
    def aggregation_interval_in_days(self):
        """
        Gets the aggregation_interval_in_days of this CreateProfileDetails.
        The time period over which to collect data for the recommendations, measured in number of days.


        :return: The aggregation_interval_in_days of this CreateProfileDetails.
        :rtype: int
        """
        return self._aggregation_interval_in_days

    @aggregation_interval_in_days.setter
    def aggregation_interval_in_days(self, aggregation_interval_in_days):
        """
        Sets the aggregation_interval_in_days of this CreateProfileDetails.
        The time period over which to collect data for the recommendations, measured in number of days.


        :param aggregation_interval_in_days: The aggregation_interval_in_days of this CreateProfileDetails.
        :type: int
        """
        self._aggregation_interval_in_days = aggregation_interval_in_days

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateProfileDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateProfileDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateProfileDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateProfileDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateProfileDetails.
        Simple key-value pair applied without any predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Exists for cross-compatibility only.

        Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateProfileDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateProfileDetails.
        Simple key-value pair applied without any predefined name, type, or namespace.
        For more information, see `Resource Tags`__. Exists for cross-compatibility only.

        Example: `{\"bar-key\": \"value\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateProfileDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def levels_configuration(self):
        """
        **[Required]** Gets the levels_configuration of this CreateProfileDetails.

        :return: The levels_configuration of this CreateProfileDetails.
        :rtype: oci.optimizer.models.LevelsConfiguration
        """
        return self._levels_configuration

    @levels_configuration.setter
    def levels_configuration(self, levels_configuration):
        """
        Sets the levels_configuration of this CreateProfileDetails.

        :param levels_configuration: The levels_configuration of this CreateProfileDetails.
        :type: oci.optimizer.models.LevelsConfiguration
        """
        self._levels_configuration = levels_configuration

    @property
    def target_compartments(self):
        """
        Gets the target_compartments of this CreateProfileDetails.

        :return: The target_compartments of this CreateProfileDetails.
        :rtype: oci.optimizer.models.TargetCompartments
        """
        return self._target_compartments

    @target_compartments.setter
    def target_compartments(self, target_compartments):
        """
        Sets the target_compartments of this CreateProfileDetails.

        :param target_compartments: The target_compartments of this CreateProfileDetails.
        :type: oci.optimizer.models.TargetCompartments
        """
        self._target_compartments = target_compartments

    @property
    def target_tags(self):
        """
        Gets the target_tags of this CreateProfileDetails.

        :return: The target_tags of this CreateProfileDetails.
        :rtype: oci.optimizer.models.TargetTags
        """
        return self._target_tags

    @target_tags.setter
    def target_tags(self, target_tags):
        """
        Sets the target_tags of this CreateProfileDetails.

        :param target_tags: The target_tags of this CreateProfileDetails.
        :type: oci.optimizer.models.TargetTags
        """
        self._target_tags = target_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Apdex(object):
    """
    An Apdex configuration rule.
    The Apdex score is computed based on how the response time of a span compares to two predefined threshold values.
    The first threshold defines the maximum response time that is considered satisfactory for the end user.
    The second one defines the maximum response time that is considered tolerable. All times larger than that will
    be considered frustrating for the end user.
    An Apdex configuration rule works by selecting a subset of spans based on a filter expression and applying the
    two threshold comparisons to compute a score for each of the selected spans.
    The rule has an \"isApplyToErrorSpans\" property that controls whether or not to compute the Apdex for spans that
    have been marked as errors. If this property is set to \"true\", then the Apdex score for error spans is computed in
    the same way as for non-error ones. If set to \"false\", then computation for error spans is skipped, and the score
    is set to \"frustrating\" regardless of the configured thresholds. The default is \"false\".
    The \"isEnabled\" property controls whether or not an Apdex score is computed and can be used to disable Apdex
    score for certain spans. The default is \"true\".
    The \"priority\" property specifies the importance of the rule within a rule set.
    Lower values indicate a higher priority. Rules with higher priorities are evaluated first in the rule set. The
    priority of the rules must be unique within a rule set.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Apdex object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param filter_text:
            The value to assign to the filter_text property of this Apdex.
        :type filter_text: str

        :param priority:
            The value to assign to the priority property of this Apdex.
        :type priority: int

        :param is_enabled:
            The value to assign to the is_enabled property of this Apdex.
        :type is_enabled: bool

        :param satisfied_response_time:
            The value to assign to the satisfied_response_time property of this Apdex.
        :type satisfied_response_time: int

        :param tolerating_response_time:
            The value to assign to the tolerating_response_time property of this Apdex.
        :type tolerating_response_time: int

        :param is_apply_to_error_spans:
            The value to assign to the is_apply_to_error_spans property of this Apdex.
        :type is_apply_to_error_spans: bool

        :param display_name:
            The value to assign to the display_name property of this Apdex.
        :type display_name: str

        """
        self.swagger_types = {
            'filter_text': 'str',
            'priority': 'int',
            'is_enabled': 'bool',
            'satisfied_response_time': 'int',
            'tolerating_response_time': 'int',
            'is_apply_to_error_spans': 'bool',
            'display_name': 'str'
        }

        self.attribute_map = {
            'filter_text': 'filterText',
            'priority': 'priority',
            'is_enabled': 'isEnabled',
            'satisfied_response_time': 'satisfiedResponseTime',
            'tolerating_response_time': 'toleratingResponseTime',
            'is_apply_to_error_spans': 'isApplyToErrorSpans',
            'display_name': 'displayName'
        }

        self._filter_text = None
        self._priority = None
        self._is_enabled = None
        self._satisfied_response_time = None
        self._tolerating_response_time = None
        self._is_apply_to_error_spans = None
        self._display_name = None

    @property
    def filter_text(self):
        """
        **[Required]** Gets the filter_text of this Apdex.
        The string that defines the Span Filter expression.


        :return: The filter_text of this Apdex.
        :rtype: str
        """
        return self._filter_text

    @filter_text.setter
    def filter_text(self, filter_text):
        """
        Sets the filter_text of this Apdex.
        The string that defines the Span Filter expression.


        :param filter_text: The filter_text of this Apdex.
        :type: str
        """
        self._filter_text = filter_text

    @property
    def priority(self):
        """
        **[Required]** Gets the priority of this Apdex.
        The priority controls the order in which multiple rules in a rule set are applied. Lower values indicate higher
        priorities. Rules with higher priority are applied first, and once a match is found, the rest of the rules are
        ignored. Rules within the same rule set cannot have the same priority.


        :return: The priority of this Apdex.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """
        Sets the priority of this Apdex.
        The priority controls the order in which multiple rules in a rule set are applied. Lower values indicate higher
        priorities. Rules with higher priority are applied first, and once a match is found, the rest of the rules are
        ignored. Rules within the same rule set cannot have the same priority.


        :param priority: The priority of this Apdex.
        :type: int
        """
        self._priority = priority

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this Apdex.
        Specifies whether the Apdex score should be computed for spans matching the rule. This can be used to disable
        Apdex score for spans that do not need or require it. The default is \"true\".


        :return: The is_enabled of this Apdex.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this Apdex.
        Specifies whether the Apdex score should be computed for spans matching the rule. This can be used to disable
        Apdex score for spans that do not need or require it. The default is \"true\".


        :param is_enabled: The is_enabled of this Apdex.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def satisfied_response_time(self):
        """
        Gets the satisfied_response_time of this Apdex.
        The maximum response time in milliseconds that is considered \"satisfactory\" for the end user.


        :return: The satisfied_response_time of this Apdex.
        :rtype: int
        """
        return self._satisfied_response_time

    @satisfied_response_time.setter
    def satisfied_response_time(self, satisfied_response_time):
        """
        Sets the satisfied_response_time of this Apdex.
        The maximum response time in milliseconds that is considered \"satisfactory\" for the end user.


        :param satisfied_response_time: The satisfied_response_time of this Apdex.
        :type: int
        """
        self._satisfied_response_time = satisfied_response_time

    @property
    def tolerating_response_time(self):
        """
        Gets the tolerating_response_time of this Apdex.
        The maximum response time in milliseconds that is considered \"tolerable\" for the end user. A response
        time beyond this threshold is considered \"frustrating\".
        This value cannot be lower than \"satisfiedResponseTime\".


        :return: The tolerating_response_time of this Apdex.
        :rtype: int
        """
        return self._tolerating_response_time

    @tolerating_response_time.setter
    def tolerating_response_time(self, tolerating_response_time):
        """
        Sets the tolerating_response_time of this Apdex.
        The maximum response time in milliseconds that is considered \"tolerable\" for the end user. A response
        time beyond this threshold is considered \"frustrating\".
        This value cannot be lower than \"satisfiedResponseTime\".


        :param tolerating_response_time: The tolerating_response_time of this Apdex.
        :type: int
        """
        self._tolerating_response_time = tolerating_response_time

    @property
    def is_apply_to_error_spans(self):
        """
        Gets the is_apply_to_error_spans of this Apdex.
        Specifies whether an Apdex score should be computed for error spans. Setting it to \"true\" means that the Apdex
        score is computed in the usual way. Setting it to \"false\" skips the Apdex computation and sets the Apdex
        score to \"frustrating\" regardless of the configured thresholds. The default is \"false\".


        :return: The is_apply_to_error_spans of this Apdex.
        :rtype: bool
        """
        return self._is_apply_to_error_spans

    @is_apply_to_error_spans.setter
    def is_apply_to_error_spans(self, is_apply_to_error_spans):
        """
        Sets the is_apply_to_error_spans of this Apdex.
        Specifies whether an Apdex score should be computed for error spans. Setting it to \"true\" means that the Apdex
        score is computed in the usual way. Setting it to \"false\" skips the Apdex computation and sets the Apdex
        score to \"frustrating\" regardless of the configured thresholds. The default is \"false\".


        :param is_apply_to_error_spans: The is_apply_to_error_spans of this Apdex.
        :type: bool
        """
        self._is_apply_to_error_spans = is_apply_to_error_spans

    @property
    def display_name(self):
        """
        Gets the display_name of this Apdex.
        The name by which a configuration entity is displayed to the end user.


        :return: The display_name of this Apdex.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Apdex.
        The name by which a configuration entity is displayed to the end user.


        :param display_name: The display_name of this Apdex.
        :type: str
        """
        self._display_name = display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FlattenProjectionPreferences(object):
    """
    The preferences for the flatten operation.
    """

    #: A constant which can be used with the create_array_index property of a FlattenProjectionPreferences.
    #: This constant has a value of "ALLOW"
    CREATE_ARRAY_INDEX_ALLOW = "ALLOW"

    #: A constant which can be used with the create_array_index property of a FlattenProjectionPreferences.
    #: This constant has a value of "DO_NOT_ALLOW"
    CREATE_ARRAY_INDEX_DO_NOT_ALLOW = "DO_NOT_ALLOW"

    #: A constant which can be used with the retain_all_attributes property of a FlattenProjectionPreferences.
    #: This constant has a value of "ALLOW"
    RETAIN_ALL_ATTRIBUTES_ALLOW = "ALLOW"

    #: A constant which can be used with the retain_all_attributes property of a FlattenProjectionPreferences.
    #: This constant has a value of "DO_NOT_ALLOW"
    RETAIN_ALL_ATTRIBUTES_DO_NOT_ALLOW = "DO_NOT_ALLOW"

    #: A constant which can be used with the ignore_null_values property of a FlattenProjectionPreferences.
    #: This constant has a value of "ALLOW"
    IGNORE_NULL_VALUES_ALLOW = "ALLOW"

    #: A constant which can be used with the ignore_null_values property of a FlattenProjectionPreferences.
    #: This constant has a value of "DO_NOT_ALLOW"
    IGNORE_NULL_VALUES_DO_NOT_ALLOW = "DO_NOT_ALLOW"

    #: A constant which can be used with the retain_parent_name_lineage property of a FlattenProjectionPreferences.
    #: This constant has a value of "ALLOW"
    RETAIN_PARENT_NAME_LINEAGE_ALLOW = "ALLOW"

    #: A constant which can be used with the retain_parent_name_lineage property of a FlattenProjectionPreferences.
    #: This constant has a value of "DO_NOT_ALLOW"
    RETAIN_PARENT_NAME_LINEAGE_DO_NOT_ALLOW = "DO_NOT_ALLOW"

    def __init__(self, **kwargs):
        """
        Initializes a new FlattenProjectionPreferences object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param create_array_index:
            The value to assign to the create_array_index property of this FlattenProjectionPreferences.
            Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type create_array_index: str

        :param retain_all_attributes:
            The value to assign to the retain_all_attributes property of this FlattenProjectionPreferences.
            Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type retain_all_attributes: str

        :param ignore_null_values:
            The value to assign to the ignore_null_values property of this FlattenProjectionPreferences.
            Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type ignore_null_values: str

        :param retain_parent_name_lineage:
            The value to assign to the retain_parent_name_lineage property of this FlattenProjectionPreferences.
            Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type retain_parent_name_lineage: str

        """
        self.swagger_types = {
            'create_array_index': 'str',
            'retain_all_attributes': 'str',
            'ignore_null_values': 'str',
            'retain_parent_name_lineage': 'str'
        }

        self.attribute_map = {
            'create_array_index': 'createArrayIndex',
            'retain_all_attributes': 'retainAllAttributes',
            'ignore_null_values': 'ignoreNullValues',
            'retain_parent_name_lineage': 'retainParentNameLineage'
        }

        self._create_array_index = None
        self._retain_all_attributes = None
        self._ignore_null_values = None
        self._retain_parent_name_lineage = None

    @property
    def create_array_index(self):
        """
        **[Required]** Gets the create_array_index of this FlattenProjectionPreferences.
        Property defining whether to create array indexes in flattened result.

        Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The create_array_index of this FlattenProjectionPreferences.
        :rtype: str
        """
        return self._create_array_index

    @create_array_index.setter
    def create_array_index(self, create_array_index):
        """
        Sets the create_array_index of this FlattenProjectionPreferences.
        Property defining whether to create array indexes in flattened result.


        :param create_array_index: The create_array_index of this FlattenProjectionPreferences.
        :type: str
        """
        allowed_values = ["ALLOW", "DO_NOT_ALLOW"]
        if not value_allowed_none_or_none_sentinel(create_array_index, allowed_values):
            create_array_index = 'UNKNOWN_ENUM_VALUE'
        self._create_array_index = create_array_index

    @property
    def retain_all_attributes(self):
        """
        **[Required]** Gets the retain_all_attributes of this FlattenProjectionPreferences.
        Property defining whether to retain all attributes in flattened result.

        Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The retain_all_attributes of this FlattenProjectionPreferences.
        :rtype: str
        """
        return self._retain_all_attributes

    @retain_all_attributes.setter
    def retain_all_attributes(self, retain_all_attributes):
        """
        Sets the retain_all_attributes of this FlattenProjectionPreferences.
        Property defining whether to retain all attributes in flattened result.


        :param retain_all_attributes: The retain_all_attributes of this FlattenProjectionPreferences.
        :type: str
        """
        allowed_values = ["ALLOW", "DO_NOT_ALLOW"]
        if not value_allowed_none_or_none_sentinel(retain_all_attributes, allowed_values):
            retain_all_attributes = 'UNKNOWN_ENUM_VALUE'
        self._retain_all_attributes = retain_all_attributes

    @property
    def ignore_null_values(self):
        """
        **[Required]** Gets the ignore_null_values of this FlattenProjectionPreferences.
        Property defining whether to ignore null values in flattened result.

        Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The ignore_null_values of this FlattenProjectionPreferences.
        :rtype: str
        """
        return self._ignore_null_values

    @ignore_null_values.setter
    def ignore_null_values(self, ignore_null_values):
        """
        Sets the ignore_null_values of this FlattenProjectionPreferences.
        Property defining whether to ignore null values in flattened result.


        :param ignore_null_values: The ignore_null_values of this FlattenProjectionPreferences.
        :type: str
        """
        allowed_values = ["ALLOW", "DO_NOT_ALLOW"]
        if not value_allowed_none_or_none_sentinel(ignore_null_values, allowed_values):
            ignore_null_values = 'UNKNOWN_ENUM_VALUE'
        self._ignore_null_values = ignore_null_values

    @property
    def retain_parent_name_lineage(self):
        """
        **[Required]** Gets the retain_parent_name_lineage of this FlattenProjectionPreferences.
        Property defining whether to retain parent name lineage.

        Allowed values for this property are: "ALLOW", "DO_NOT_ALLOW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The retain_parent_name_lineage of this FlattenProjectionPreferences.
        :rtype: str
        """
        return self._retain_parent_name_lineage

    @retain_parent_name_lineage.setter
    def retain_parent_name_lineage(self, retain_parent_name_lineage):
        """
        Sets the retain_parent_name_lineage of this FlattenProjectionPreferences.
        Property defining whether to retain parent name lineage.


        :param retain_parent_name_lineage: The retain_parent_name_lineage of this FlattenProjectionPreferences.
        :type: str
        """
        allowed_values = ["ALLOW", "DO_NOT_ALLOW"]
        if not value_allowed_none_or_none_sentinel(retain_parent_name_lineage, allowed_values):
            retain_parent_name_lineage = 'UNKNOWN_ENUM_VALUE'
        self._retain_parent_name_lineage = retain_parent_name_lineage

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CloudAutonomousVmCluster(object):
    """
    Details of the cloud Autonomous VM cluster.
    """

    #: A constant which can be used with the lifecycle_state property of a CloudAutonomousVmCluster.
    #: This constant has a value of "PROVISIONING"
    LIFECYCLE_STATE_PROVISIONING = "PROVISIONING"

    #: A constant which can be used with the lifecycle_state property of a CloudAutonomousVmCluster.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a CloudAutonomousVmCluster.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a CloudAutonomousVmCluster.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a CloudAutonomousVmCluster.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a CloudAutonomousVmCluster.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a CloudAutonomousVmCluster.
    #: This constant has a value of "MAINTENANCE_IN_PROGRESS"
    LIFECYCLE_STATE_MAINTENANCE_IN_PROGRESS = "MAINTENANCE_IN_PROGRESS"

    #: A constant which can be used with the license_model property of a CloudAutonomousVmCluster.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a CloudAutonomousVmCluster.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new CloudAutonomousVmCluster object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CloudAutonomousVmCluster.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CloudAutonomousVmCluster.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this CloudAutonomousVmCluster.
        :type description: str

        :param availability_domain:
            The value to assign to the availability_domain property of this CloudAutonomousVmCluster.
        :type availability_domain: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CloudAutonomousVmCluster.
        :type subnet_id: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CloudAutonomousVmCluster.
        :type nsg_ids: list[str]

        :param last_update_history_entry_id:
            The value to assign to the last_update_history_entry_id property of this CloudAutonomousVmCluster.
        :type last_update_history_entry_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CloudAutonomousVmCluster.
            Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param display_name:
            The value to assign to the display_name property of this CloudAutonomousVmCluster.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this CloudAutonomousVmCluster.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this CloudAutonomousVmCluster.
        :type time_updated: datetime

        :param cluster_time_zone:
            The value to assign to the cluster_time_zone property of this CloudAutonomousVmCluster.
        :type cluster_time_zone: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this CloudAutonomousVmCluster.
        :type lifecycle_details: str

        :param hostname:
            The value to assign to the hostname property of this CloudAutonomousVmCluster.
        :type hostname: str

        :param domain:
            The value to assign to the domain property of this CloudAutonomousVmCluster.
        :type domain: str

        :param cloud_exadata_infrastructure_id:
            The value to assign to the cloud_exadata_infrastructure_id property of this CloudAutonomousVmCluster.
        :type cloud_exadata_infrastructure_id: str

        :param shape:
            The value to assign to the shape property of this CloudAutonomousVmCluster.
        :type shape: str

        :param node_count:
            The value to assign to the node_count property of this CloudAutonomousVmCluster.
        :type node_count: int

        :param data_storage_size_in_tbs:
            The value to assign to the data_storage_size_in_tbs property of this CloudAutonomousVmCluster.
        :type data_storage_size_in_tbs: float

        :param data_storage_size_in_gbs:
            The value to assign to the data_storage_size_in_gbs property of this CloudAutonomousVmCluster.
        :type data_storage_size_in_gbs: float

        :param cpu_core_count:
            The value to assign to the cpu_core_count property of this CloudAutonomousVmCluster.
        :type cpu_core_count: int

        :param ocpu_count:
            The value to assign to the ocpu_count property of this CloudAutonomousVmCluster.
        :type ocpu_count: float

        :param memory_size_in_gbs:
            The value to assign to the memory_size_in_gbs property of this CloudAutonomousVmCluster.
        :type memory_size_in_gbs: int

        :param license_model:
            The value to assign to the license_model property of this CloudAutonomousVmCluster.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type license_model: str

        :param last_maintenance_run_id:
            The value to assign to the last_maintenance_run_id property of this CloudAutonomousVmCluster.
        :type last_maintenance_run_id: str

        :param next_maintenance_run_id:
            The value to assign to the next_maintenance_run_id property of this CloudAutonomousVmCluster.
        :type next_maintenance_run_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CloudAutonomousVmCluster.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CloudAutonomousVmCluster.
        :type defined_tags: dict(str, dict(str, object))

        :param available_cpus:
            The value to assign to the available_cpus property of this CloudAutonomousVmCluster.
        :type available_cpus: float

        :param reclaimable_cpus:
            The value to assign to the reclaimable_cpus property of this CloudAutonomousVmCluster.
        :type reclaimable_cpus: float

        :param available_container_databases:
            The value to assign to the available_container_databases property of this CloudAutonomousVmCluster.
        :type available_container_databases: int

        :param total_container_databases:
            The value to assign to the total_container_databases property of this CloudAutonomousVmCluster.
        :type total_container_databases: int

        :param available_autonomous_data_storage_size_in_tbs:
            The value to assign to the available_autonomous_data_storage_size_in_tbs property of this CloudAutonomousVmCluster.
        :type available_autonomous_data_storage_size_in_tbs: float

        :param autonomous_data_storage_size_in_tbs:
            The value to assign to the autonomous_data_storage_size_in_tbs property of this CloudAutonomousVmCluster.
        :type autonomous_data_storage_size_in_tbs: float

        :param db_node_storage_size_in_gbs:
            The value to assign to the db_node_storage_size_in_gbs property of this CloudAutonomousVmCluster.
        :type db_node_storage_size_in_gbs: int

        :param memory_per_oracle_compute_unit_in_gbs:
            The value to assign to the memory_per_oracle_compute_unit_in_gbs property of this CloudAutonomousVmCluster.
        :type memory_per_oracle_compute_unit_in_gbs: int

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'availability_domain': 'str',
            'subnet_id': 'str',
            'nsg_ids': 'list[str]',
            'last_update_history_entry_id': 'str',
            'lifecycle_state': 'str',
            'display_name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'cluster_time_zone': 'str',
            'lifecycle_details': 'str',
            'hostname': 'str',
            'domain': 'str',
            'cloud_exadata_infrastructure_id': 'str',
            'shape': 'str',
            'node_count': 'int',
            'data_storage_size_in_tbs': 'float',
            'data_storage_size_in_gbs': 'float',
            'cpu_core_count': 'int',
            'ocpu_count': 'float',
            'memory_size_in_gbs': 'int',
            'license_model': 'str',
            'last_maintenance_run_id': 'str',
            'next_maintenance_run_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'available_cpus': 'float',
            'reclaimable_cpus': 'float',
            'available_container_databases': 'int',
            'total_container_databases': 'int',
            'available_autonomous_data_storage_size_in_tbs': 'float',
            'autonomous_data_storage_size_in_tbs': 'float',
            'db_node_storage_size_in_gbs': 'int',
            'memory_per_oracle_compute_unit_in_gbs': 'int'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'availability_domain': 'availabilityDomain',
            'subnet_id': 'subnetId',
            'nsg_ids': 'nsgIds',
            'last_update_history_entry_id': 'lastUpdateHistoryEntryId',
            'lifecycle_state': 'lifecycleState',
            'display_name': 'displayName',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'cluster_time_zone': 'clusterTimeZone',
            'lifecycle_details': 'lifecycleDetails',
            'hostname': 'hostname',
            'domain': 'domain',
            'cloud_exadata_infrastructure_id': 'cloudExadataInfrastructureId',
            'shape': 'shape',
            'node_count': 'nodeCount',
            'data_storage_size_in_tbs': 'dataStorageSizeInTBs',
            'data_storage_size_in_gbs': 'dataStorageSizeInGBs',
            'cpu_core_count': 'cpuCoreCount',
            'ocpu_count': 'ocpuCount',
            'memory_size_in_gbs': 'memorySizeInGBs',
            'license_model': 'licenseModel',
            'last_maintenance_run_id': 'lastMaintenanceRunId',
            'next_maintenance_run_id': 'nextMaintenanceRunId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'available_cpus': 'availableCpus',
            'reclaimable_cpus': 'reclaimableCpus',
            'available_container_databases': 'availableContainerDatabases',
            'total_container_databases': 'totalContainerDatabases',
            'available_autonomous_data_storage_size_in_tbs': 'availableAutonomousDataStorageSizeInTBs',
            'autonomous_data_storage_size_in_tbs': 'autonomousDataStorageSizeInTBs',
            'db_node_storage_size_in_gbs': 'dbNodeStorageSizeInGBs',
            'memory_per_oracle_compute_unit_in_gbs': 'memoryPerOracleComputeUnitInGBs'
        }

        self._id = None
        self._compartment_id = None
        self._description = None
        self._availability_domain = None
        self._subnet_id = None
        self._nsg_ids = None
        self._last_update_history_entry_id = None
        self._lifecycle_state = None
        self._display_name = None
        self._time_created = None
        self._time_updated = None
        self._cluster_time_zone = None
        self._lifecycle_details = None
        self._hostname = None
        self._domain = None
        self._cloud_exadata_infrastructure_id = None
        self._shape = None
        self._node_count = None
        self._data_storage_size_in_tbs = None
        self._data_storage_size_in_gbs = None
        self._cpu_core_count = None
        self._ocpu_count = None
        self._memory_size_in_gbs = None
        self._license_model = None
        self._last_maintenance_run_id = None
        self._next_maintenance_run_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._available_cpus = None
        self._reclaimable_cpus = None
        self._available_container_databases = None
        self._total_container_databases = None
        self._available_autonomous_data_storage_size_in_tbs = None
        self._autonomous_data_storage_size_in_tbs = None
        self._db_node_storage_size_in_gbs = None
        self._memory_per_oracle_compute_unit_in_gbs = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this CloudAutonomousVmCluster.
        The `OCID`__ of the Cloud Autonomous VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CloudAutonomousVmCluster.
        The `OCID`__ of the Cloud Autonomous VM cluster.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this CloudAutonomousVmCluster.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CloudAutonomousVmCluster.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this CloudAutonomousVmCluster.
        User defined description of the cloud Autonomous VM cluster.


        :return: The description of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CloudAutonomousVmCluster.
        User defined description of the cloud Autonomous VM cluster.


        :param description: The description of this CloudAutonomousVmCluster.
        :type: str
        """
        self._description = description

    @property
    def availability_domain(self):
        """
        **[Required]** Gets the availability_domain of this CloudAutonomousVmCluster.
        The name of the availability domain that the cloud Autonomous VM cluster is located in.


        :return: The availability_domain of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CloudAutonomousVmCluster.
        The name of the availability domain that the cloud Autonomous VM cluster is located in.


        :param availability_domain: The availability_domain of this CloudAutonomousVmCluster.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the subnet the cloud Autonomous VM Cluster is associated with.

        **Subnet Restrictions:**
        - For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.

        These subnets are used by the Oracle Clusterware private interconnect on the database instance.
        Specifying an overlapping subnet will cause the private interconnect to malfunction.
        This restriction applies to both the client subnet and backup subnet.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the subnet the cloud Autonomous VM Cluster is associated with.

        **Subnet Restrictions:**
        - For Exadata and virtual machine 2-node RAC DB systems, do not use a subnet that overlaps with 192.168.128.0/20.

        These subnets are used by the Oracle Clusterware private interconnect on the database instance.
        Specifying an overlapping subnet will cause the private interconnect to malfunction.
        This restriction applies to both the client subnet and backup subnet.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this CloudAutonomousVmCluster.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CloudAutonomousVmCluster.
        The list of `OCIDs`__ for the network security groups (NSGs) to which this resource belongs. Setting this to an empty list removes all resources from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - A network security group (NSG) is optional for Autonomous Databases with private access. The nsgIds list can be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this CloudAutonomousVmCluster.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CloudAutonomousVmCluster.
        The list of `OCIDs`__ for the network security groups (NSGs) to which this resource belongs. Setting this to an empty list removes all resources from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - A network security group (NSG) is optional for Autonomous Databases with private access. The nsgIds list can be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this CloudAutonomousVmCluster.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def last_update_history_entry_id(self):
        """
        Gets the last_update_history_entry_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the last maintenance update history. This value is updated when a maintenance update starts.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The last_update_history_entry_id of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._last_update_history_entry_id

    @last_update_history_entry_id.setter
    def last_update_history_entry_id(self, last_update_history_entry_id):
        """
        Sets the last_update_history_entry_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the last maintenance update history. This value is updated when a maintenance update starts.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param last_update_history_entry_id: The last_update_history_entry_id of this CloudAutonomousVmCluster.
        :type: str
        """
        self._last_update_history_entry_id = last_update_history_entry_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this CloudAutonomousVmCluster.
        The current state of the cloud Autonomous VM cluster.

        Allowed values for this property are: "PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this CloudAutonomousVmCluster.
        The current state of the cloud Autonomous VM cluster.


        :param lifecycle_state: The lifecycle_state of this CloudAutonomousVmCluster.
        :type: str
        """
        allowed_values = ["PROVISIONING", "AVAILABLE", "UPDATING", "TERMINATING", "TERMINATED", "FAILED", "MAINTENANCE_IN_PROGRESS"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CloudAutonomousVmCluster.
        The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.


        :return: The display_name of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CloudAutonomousVmCluster.
        The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.


        :param display_name: The display_name of this CloudAutonomousVmCluster.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        Gets the time_created of this CloudAutonomousVmCluster.
        The date and time that the cloud Autonomous VM cluster was created.


        :return: The time_created of this CloudAutonomousVmCluster.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this CloudAutonomousVmCluster.
        The date and time that the cloud Autonomous VM cluster was created.


        :param time_created: The time_created of this CloudAutonomousVmCluster.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this CloudAutonomousVmCluster.
        The last date and time that the cloud Autonomous VM cluster was updated.


        :return: The time_updated of this CloudAutonomousVmCluster.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this CloudAutonomousVmCluster.
        The last date and time that the cloud Autonomous VM cluster was updated.


        :param time_updated: The time_updated of this CloudAutonomousVmCluster.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def cluster_time_zone(self):
        """
        Gets the cluster_time_zone of this CloudAutonomousVmCluster.
        The time zone of the Cloud Autonomous VM Cluster.


        :return: The cluster_time_zone of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._cluster_time_zone

    @cluster_time_zone.setter
    def cluster_time_zone(self, cluster_time_zone):
        """
        Sets the cluster_time_zone of this CloudAutonomousVmCluster.
        The time zone of the Cloud Autonomous VM Cluster.


        :param cluster_time_zone: The cluster_time_zone of this CloudAutonomousVmCluster.
        :type: str
        """
        self._cluster_time_zone = cluster_time_zone

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this CloudAutonomousVmCluster.
        Additional information about the current lifecycle state.


        :return: The lifecycle_details of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this CloudAutonomousVmCluster.
        Additional information about the current lifecycle state.


        :param lifecycle_details: The lifecycle_details of this CloudAutonomousVmCluster.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def hostname(self):
        """
        Gets the hostname of this CloudAutonomousVmCluster.
        The hostname for the cloud Autonomous VM cluster.


        :return: The hostname of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this CloudAutonomousVmCluster.
        The hostname for the cloud Autonomous VM cluster.


        :param hostname: The hostname of this CloudAutonomousVmCluster.
        :type: str
        """
        self._hostname = hostname

    @property
    def domain(self):
        """
        Gets the domain of this CloudAutonomousVmCluster.
        The domain name for the cloud Autonomous VM cluster.


        :return: The domain of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this CloudAutonomousVmCluster.
        The domain name for the cloud Autonomous VM cluster.


        :param domain: The domain of this CloudAutonomousVmCluster.
        :type: str
        """
        self._domain = domain

    @property
    def cloud_exadata_infrastructure_id(self):
        """
        **[Required]** Gets the cloud_exadata_infrastructure_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the cloud Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The cloud_exadata_infrastructure_id of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._cloud_exadata_infrastructure_id

    @cloud_exadata_infrastructure_id.setter
    def cloud_exadata_infrastructure_id(self, cloud_exadata_infrastructure_id):
        """
        Sets the cloud_exadata_infrastructure_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the cloud Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param cloud_exadata_infrastructure_id: The cloud_exadata_infrastructure_id of this CloudAutonomousVmCluster.
        :type: str
        """
        self._cloud_exadata_infrastructure_id = cloud_exadata_infrastructure_id

    @property
    def shape(self):
        """
        Gets the shape of this CloudAutonomousVmCluster.
        The model name of the Exadata hardware running the cloud Autonomous VM cluster.


        :return: The shape of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._shape

    @shape.setter
    def shape(self, shape):
        """
        Sets the shape of this CloudAutonomousVmCluster.
        The model name of the Exadata hardware running the cloud Autonomous VM cluster.


        :param shape: The shape of this CloudAutonomousVmCluster.
        :type: str
        """
        self._shape = shape

    @property
    def node_count(self):
        """
        Gets the node_count of this CloudAutonomousVmCluster.
        The number of database servers in the cloud VM cluster.


        :return: The node_count of this CloudAutonomousVmCluster.
        :rtype: int
        """
        return self._node_count

    @node_count.setter
    def node_count(self, node_count):
        """
        Sets the node_count of this CloudAutonomousVmCluster.
        The number of database servers in the cloud VM cluster.


        :param node_count: The node_count of this CloudAutonomousVmCluster.
        :type: int
        """
        self._node_count = node_count

    @property
    def data_storage_size_in_tbs(self):
        """
        Gets the data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        The total data storage allocated, in terabytes (TB).


        :return: The data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        :rtype: float
        """
        return self._data_storage_size_in_tbs

    @data_storage_size_in_tbs.setter
    def data_storage_size_in_tbs(self, data_storage_size_in_tbs):
        """
        Sets the data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        The total data storage allocated, in terabytes (TB).


        :param data_storage_size_in_tbs: The data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        :type: float
        """
        self._data_storage_size_in_tbs = data_storage_size_in_tbs

    @property
    def data_storage_size_in_gbs(self):
        """
        Gets the data_storage_size_in_gbs of this CloudAutonomousVmCluster.
        The total data storage allocated, in gigabytes (GB).


        :return: The data_storage_size_in_gbs of this CloudAutonomousVmCluster.
        :rtype: float
        """
        return self._data_storage_size_in_gbs

    @data_storage_size_in_gbs.setter
    def data_storage_size_in_gbs(self, data_storage_size_in_gbs):
        """
        Sets the data_storage_size_in_gbs of this CloudAutonomousVmCluster.
        The total data storage allocated, in gigabytes (GB).


        :param data_storage_size_in_gbs: The data_storage_size_in_gbs of this CloudAutonomousVmCluster.
        :type: float
        """
        self._data_storage_size_in_gbs = data_storage_size_in_gbs

    @property
    def cpu_core_count(self):
        """
        Gets the cpu_core_count of this CloudAutonomousVmCluster.
        The number of CPU cores enabled on the cloud Autonomous VM cluster.


        :return: The cpu_core_count of this CloudAutonomousVmCluster.
        :rtype: int
        """
        return self._cpu_core_count

    @cpu_core_count.setter
    def cpu_core_count(self, cpu_core_count):
        """
        Sets the cpu_core_count of this CloudAutonomousVmCluster.
        The number of CPU cores enabled on the cloud Autonomous VM cluster.


        :param cpu_core_count: The cpu_core_count of this CloudAutonomousVmCluster.
        :type: int
        """
        self._cpu_core_count = cpu_core_count

    @property
    def ocpu_count(self):
        """
        Gets the ocpu_count of this CloudAutonomousVmCluster.
        The number of CPU cores enabled on the cloud Autonomous VM cluster. Only 1 decimal place is allowed for the fractional part.


        :return: The ocpu_count of this CloudAutonomousVmCluster.
        :rtype: float
        """
        return self._ocpu_count

    @ocpu_count.setter
    def ocpu_count(self, ocpu_count):
        """
        Sets the ocpu_count of this CloudAutonomousVmCluster.
        The number of CPU cores enabled on the cloud Autonomous VM cluster. Only 1 decimal place is allowed for the fractional part.


        :param ocpu_count: The ocpu_count of this CloudAutonomousVmCluster.
        :type: float
        """
        self._ocpu_count = ocpu_count

    @property
    def memory_size_in_gbs(self):
        """
        Gets the memory_size_in_gbs of this CloudAutonomousVmCluster.
        The memory allocated in GBs.


        :return: The memory_size_in_gbs of this CloudAutonomousVmCluster.
        :rtype: int
        """
        return self._memory_size_in_gbs

    @memory_size_in_gbs.setter
    def memory_size_in_gbs(self, memory_size_in_gbs):
        """
        Sets the memory_size_in_gbs of this CloudAutonomousVmCluster.
        The memory allocated in GBs.


        :param memory_size_in_gbs: The memory_size_in_gbs of this CloudAutonomousVmCluster.
        :type: int
        """
        self._memory_size_in_gbs = memory_size_in_gbs

    @property
    def license_model(self):
        """
        Gets the license_model of this CloudAutonomousVmCluster.
        The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud.
        License Included allows you to subscribe to new Oracle Database software licenses and the Database service.
        Note that when provisioning an Autonomous Database on `dedicated Exadata infrastructure`__, this attribute must be null because the attribute is already set at the
        Autonomous Exadata Infrastructure level. When using `shared Exadata infrastructure`__, if a value is not specified, the system will supply the value of `BRING_YOUR_OWN_LICENSE`.

        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html
        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The license_model of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this CloudAutonomousVmCluster.
        The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud.
        License Included allows you to subscribe to new Oracle Database software licenses and the Database service.
        Note that when provisioning an Autonomous Database on `dedicated Exadata infrastructure`__, this attribute must be null because the attribute is already set at the
        Autonomous Exadata Infrastructure level. When using `shared Exadata infrastructure`__, if a value is not specified, the system will supply the value of `BRING_YOUR_OWN_LICENSE`.

        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html
        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html


        :param license_model: The license_model of this CloudAutonomousVmCluster.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            license_model = 'UNKNOWN_ENUM_VALUE'
        self._license_model = license_model

    @property
    def last_maintenance_run_id(self):
        """
        Gets the last_maintenance_run_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The last_maintenance_run_id of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._last_maintenance_run_id

    @last_maintenance_run_id.setter
    def last_maintenance_run_id(self, last_maintenance_run_id):
        """
        Sets the last_maintenance_run_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the last maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param last_maintenance_run_id: The last_maintenance_run_id of this CloudAutonomousVmCluster.
        :type: str
        """
        self._last_maintenance_run_id = last_maintenance_run_id

    @property
    def next_maintenance_run_id(self):
        """
        Gets the next_maintenance_run_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The next_maintenance_run_id of this CloudAutonomousVmCluster.
        :rtype: str
        """
        return self._next_maintenance_run_id

    @next_maintenance_run_id.setter
    def next_maintenance_run_id(self, next_maintenance_run_id):
        """
        Sets the next_maintenance_run_id of this CloudAutonomousVmCluster.
        The `OCID`__ of the next maintenance run.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param next_maintenance_run_id: The next_maintenance_run_id of this CloudAutonomousVmCluster.
        :type: str
        """
        self._next_maintenance_run_id = next_maintenance_run_id

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CloudAutonomousVmCluster.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CloudAutonomousVmCluster.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CloudAutonomousVmCluster.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CloudAutonomousVmCluster.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CloudAutonomousVmCluster.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CloudAutonomousVmCluster.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CloudAutonomousVmCluster.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CloudAutonomousVmCluster.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def available_cpus(self):
        """
        Gets the available_cpus of this CloudAutonomousVmCluster.
        CPU cores available for allocation to Autonomous Databases.


        :return: The available_cpus of this CloudAutonomousVmCluster.
        :rtype: float
        """
        return self._available_cpus

    @available_cpus.setter
    def available_cpus(self, available_cpus):
        """
        Sets the available_cpus of this CloudAutonomousVmCluster.
        CPU cores available for allocation to Autonomous Databases.


        :param available_cpus: The available_cpus of this CloudAutonomousVmCluster.
        :type: float
        """
        self._available_cpus = available_cpus

    @property
    def reclaimable_cpus(self):
        """
        Gets the reclaimable_cpus of this CloudAutonomousVmCluster.
        CPU cores that continue to be included in the count of OCPUs available to the Autonomous Container Database even after one of its Autonomous Database is terminated or scaled down. You can release them to the available OCPUs at its parent AVMC level by restarting the Autonomous Container Database.


        :return: The reclaimable_cpus of this CloudAutonomousVmCluster.
        :rtype: float
        """
        return self._reclaimable_cpus

    @reclaimable_cpus.setter
    def reclaimable_cpus(self, reclaimable_cpus):
        """
        Sets the reclaimable_cpus of this CloudAutonomousVmCluster.
        CPU cores that continue to be included in the count of OCPUs available to the Autonomous Container Database even after one of its Autonomous Database is terminated or scaled down. You can release them to the available OCPUs at its parent AVMC level by restarting the Autonomous Container Database.


        :param reclaimable_cpus: The reclaimable_cpus of this CloudAutonomousVmCluster.
        :type: float
        """
        self._reclaimable_cpus = reclaimable_cpus

    @property
    def available_container_databases(self):
        """
        Gets the available_container_databases of this CloudAutonomousVmCluster.
        The number of Autonomous Container Databases that can be created with the currently available local storage.


        :return: The available_container_databases of this CloudAutonomousVmCluster.
        :rtype: int
        """
        return self._available_container_databases

    @available_container_databases.setter
    def available_container_databases(self, available_container_databases):
        """
        Sets the available_container_databases of this CloudAutonomousVmCluster.
        The number of Autonomous Container Databases that can be created with the currently available local storage.


        :param available_container_databases: The available_container_databases of this CloudAutonomousVmCluster.
        :type: int
        """
        self._available_container_databases = available_container_databases

    @property
    def total_container_databases(self):
        """
        Gets the total_container_databases of this CloudAutonomousVmCluster.
        The total number of Autonomous Container Databases that can be created with the allocated local storage.


        :return: The total_container_databases of this CloudAutonomousVmCluster.
        :rtype: int
        """
        return self._total_container_databases

    @total_container_databases.setter
    def total_container_databases(self, total_container_databases):
        """
        Sets the total_container_databases of this CloudAutonomousVmCluster.
        The total number of Autonomous Container Databases that can be created with the allocated local storage.


        :param total_container_databases: The total_container_databases of this CloudAutonomousVmCluster.
        :type: int
        """
        self._total_container_databases = total_container_databases

    @property
    def available_autonomous_data_storage_size_in_tbs(self):
        """
        Gets the available_autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        The data disk group size available for Autonomous Databases, in TBs.


        :return: The available_autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        :rtype: float
        """
        return self._available_autonomous_data_storage_size_in_tbs

    @available_autonomous_data_storage_size_in_tbs.setter
    def available_autonomous_data_storage_size_in_tbs(self, available_autonomous_data_storage_size_in_tbs):
        """
        Sets the available_autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        The data disk group size available for Autonomous Databases, in TBs.


        :param available_autonomous_data_storage_size_in_tbs: The available_autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        :type: float
        """
        self._available_autonomous_data_storage_size_in_tbs = available_autonomous_data_storage_size_in_tbs

    @property
    def autonomous_data_storage_size_in_tbs(self):
        """
        Gets the autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        The data disk group size allocated for Autonomous Databases, in TBs.


        :return: The autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        :rtype: float
        """
        return self._autonomous_data_storage_size_in_tbs

    @autonomous_data_storage_size_in_tbs.setter
    def autonomous_data_storage_size_in_tbs(self, autonomous_data_storage_size_in_tbs):
        """
        Sets the autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        The data disk group size allocated for Autonomous Databases, in TBs.


        :param autonomous_data_storage_size_in_tbs: The autonomous_data_storage_size_in_tbs of this CloudAutonomousVmCluster.
        :type: float
        """
        self._autonomous_data_storage_size_in_tbs = autonomous_data_storage_size_in_tbs

    @property
    def db_node_storage_size_in_gbs(self):
        """
        Gets the db_node_storage_size_in_gbs of this CloudAutonomousVmCluster.
        The local node storage allocated in GBs.


        :return: The db_node_storage_size_in_gbs of this CloudAutonomousVmCluster.
        :rtype: int
        """
        return self._db_node_storage_size_in_gbs

    @db_node_storage_size_in_gbs.setter
    def db_node_storage_size_in_gbs(self, db_node_storage_size_in_gbs):
        """
        Sets the db_node_storage_size_in_gbs of this CloudAutonomousVmCluster.
        The local node storage allocated in GBs.


        :param db_node_storage_size_in_gbs: The db_node_storage_size_in_gbs of this CloudAutonomousVmCluster.
        :type: int
        """
        self._db_node_storage_size_in_gbs = db_node_storage_size_in_gbs

    @property
    def memory_per_oracle_compute_unit_in_gbs(self):
        """
        Gets the memory_per_oracle_compute_unit_in_gbs of this CloudAutonomousVmCluster.
        The amount of memory (in GBs) enabled per each OCPU core.


        :return: The memory_per_oracle_compute_unit_in_gbs of this CloudAutonomousVmCluster.
        :rtype: int
        """
        return self._memory_per_oracle_compute_unit_in_gbs

    @memory_per_oracle_compute_unit_in_gbs.setter
    def memory_per_oracle_compute_unit_in_gbs(self, memory_per_oracle_compute_unit_in_gbs):
        """
        Sets the memory_per_oracle_compute_unit_in_gbs of this CloudAutonomousVmCluster.
        The amount of memory (in GBs) enabled per each OCPU core.


        :param memory_per_oracle_compute_unit_in_gbs: The memory_per_oracle_compute_unit_in_gbs of this CloudAutonomousVmCluster.
        :type: int
        """
        self._memory_per_oracle_compute_unit_in_gbs = memory_per_oracle_compute_unit_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .traffic_protocol_parameters import TrafficProtocolParameters
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TcpTrafficProtocolParameters(TrafficProtocolParameters):
    """
    Defines the `TrafficProtocolParameters` configuration for the TCP protocol.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TcpTrafficProtocolParameters object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.TcpTrafficProtocolParameters.type` attribute
        of this class is ``TCP`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this TcpTrafficProtocolParameters.
            Allowed values for this property are: "TCP", "UDP", "ICMP"
        :type type: str

        :param source_port:
            The value to assign to the source_port property of this TcpTrafficProtocolParameters.
        :type source_port: int

        :param destination_port:
            The value to assign to the destination_port property of this TcpTrafficProtocolParameters.
        :type destination_port: int

        """
        self.swagger_types = {
            'type': 'str',
            'source_port': 'int',
            'destination_port': 'int'
        }

        self.attribute_map = {
            'type': 'type',
            'source_port': 'sourcePort',
            'destination_port': 'destinationPort'
        }

        self._type = None
        self._source_port = None
        self._destination_port = None
        self._type = 'TCP'

    @property
    def source_port(self):
        """
        Gets the source_port of this TcpTrafficProtocolParameters.
        The source port to use in a `PathAnalyzerTest`.


        :return: The source_port of this TcpTrafficProtocolParameters.
        :rtype: int
        """
        return self._source_port

    @source_port.setter
    def source_port(self, source_port):
        """
        Sets the source_port of this TcpTrafficProtocolParameters.
        The source port to use in a `PathAnalyzerTest`.


        :param source_port: The source_port of this TcpTrafficProtocolParameters.
        :type: int
        """
        self._source_port = source_port

    @property
    def destination_port(self):
        """
        **[Required]** Gets the destination_port of this TcpTrafficProtocolParameters.
        The destination port to use in a `PathAnalyzerTest`.


        :return: The destination_port of this TcpTrafficProtocolParameters.
        :rtype: int
        """
        return self._destination_port

    @destination_port.setter
    def destination_port(self, destination_port):
        """
        Sets the destination_port of this TcpTrafficProtocolParameters.
        The destination port to use in a `PathAnalyzerTest`.


        :param destination_port: The destination_port of this TcpTrafficProtocolParameters.
        :type: int
        """
        self._destination_port = destination_port

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .vertical_scaling_schedule_details import VerticalScalingScheduleDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DayBasedVerticalScalingScheduleDetails(VerticalScalingScheduleDetails):
    """
    Details of day based vertical scaling schedule.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DayBasedVerticalScalingScheduleDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.bds.models.DayBasedVerticalScalingScheduleDetails.schedule_type` attribute
        of this class is ``DAY_BASED`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param schedule_type:
            The value to assign to the schedule_type property of this DayBasedVerticalScalingScheduleDetails.
        :type schedule_type: str

        :param time_and_vertical_scaling_config:
            The value to assign to the time_and_vertical_scaling_config property of this DayBasedVerticalScalingScheduleDetails.
        :type time_and_vertical_scaling_config: list[oci.bds.models.TimeAndVerticalScalingConfig]

        """
        self.swagger_types = {
            'schedule_type': 'str',
            'time_and_vertical_scaling_config': 'list[TimeAndVerticalScalingConfig]'
        }

        self.attribute_map = {
            'schedule_type': 'scheduleType',
            'time_and_vertical_scaling_config': 'timeAndVerticalScalingConfig'
        }

        self._schedule_type = None
        self._time_and_vertical_scaling_config = None
        self._schedule_type = 'DAY_BASED'

    @property
    def time_and_vertical_scaling_config(self):
        """
        Gets the time_and_vertical_scaling_config of this DayBasedVerticalScalingScheduleDetails.

        :return: The time_and_vertical_scaling_config of this DayBasedVerticalScalingScheduleDetails.
        :rtype: list[oci.bds.models.TimeAndVerticalScalingConfig]
        """
        return self._time_and_vertical_scaling_config

    @time_and_vertical_scaling_config.setter
    def time_and_vertical_scaling_config(self, time_and_vertical_scaling_config):
        """
        Sets the time_and_vertical_scaling_config of this DayBasedVerticalScalingScheduleDetails.

        :param time_and_vertical_scaling_config: The time_and_vertical_scaling_config of this DayBasedVerticalScalingScheduleDetails.
        :type: list[oci.bds.models.TimeAndVerticalScalingConfig]
        """
        self._time_and_vertical_scaling_config = time_and_vertical_scaling_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_tools_connection import DatabaseToolsConnection
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseToolsConnectionOracleDatabase(DatabaseToolsConnection):
    """
    Database Tools connection of an Oracle Database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseToolsConnectionOracleDatabase object with values from keyword arguments. The default value of the :py:attr:`~oci.database_tools.models.DatabaseToolsConnectionOracleDatabase.type` attribute
        of this class is ``ORACLE_DATABASE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this DatabaseToolsConnectionOracleDatabase.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this DatabaseToolsConnectionOracleDatabase.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this DatabaseToolsConnectionOracleDatabase.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this DatabaseToolsConnectionOracleDatabase.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this DatabaseToolsConnectionOracleDatabase.
        :type lifecycle_details: str

        :param time_created:
            The value to assign to the time_created property of this DatabaseToolsConnectionOracleDatabase.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this DatabaseToolsConnectionOracleDatabase.
        :type time_updated: datetime

        :param defined_tags:
            The value to assign to the defined_tags property of this DatabaseToolsConnectionOracleDatabase.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this DatabaseToolsConnectionOracleDatabase.
        :type freeform_tags: dict(str, str)

        :param system_tags:
            The value to assign to the system_tags property of this DatabaseToolsConnectionOracleDatabase.
        :type system_tags: dict(str, dict(str, object))

        :param type:
            The value to assign to the type property of this DatabaseToolsConnectionOracleDatabase.
            Allowed values for this property are: "ORACLE_DATABASE", "MYSQL"
        :type type: str

        :param related_resource:
            The value to assign to the related_resource property of this DatabaseToolsConnectionOracleDatabase.
        :type related_resource: oci.database_tools.models.DatabaseToolsRelatedResource

        :param connection_string:
            The value to assign to the connection_string property of this DatabaseToolsConnectionOracleDatabase.
        :type connection_string: str

        :param user_name:
            The value to assign to the user_name property of this DatabaseToolsConnectionOracleDatabase.
        :type user_name: str

        :param user_password:
            The value to assign to the user_password property of this DatabaseToolsConnectionOracleDatabase.
        :type user_password: oci.database_tools.models.DatabaseToolsUserPassword

        :param advanced_properties:
            The value to assign to the advanced_properties property of this DatabaseToolsConnectionOracleDatabase.
        :type advanced_properties: dict(str, str)

        :param key_stores:
            The value to assign to the key_stores property of this DatabaseToolsConnectionOracleDatabase.
        :type key_stores: list[oci.database_tools.models.DatabaseToolsKeyStore]

        :param private_endpoint_id:
            The value to assign to the private_endpoint_id property of this DatabaseToolsConnectionOracleDatabase.
        :type private_endpoint_id: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'system_tags': 'dict(str, dict(str, object))',
            'type': 'str',
            'related_resource': 'DatabaseToolsRelatedResource',
            'connection_string': 'str',
            'user_name': 'str',
            'user_password': 'DatabaseToolsUserPassword',
            'advanced_properties': 'dict(str, str)',
            'key_stores': 'list[DatabaseToolsKeyStore]',
            'private_endpoint_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'system_tags': 'systemTags',
            'type': 'type',
            'related_resource': 'relatedResource',
            'connection_string': 'connectionString',
            'user_name': 'userName',
            'user_password': 'userPassword',
            'advanced_properties': 'advancedProperties',
            'key_stores': 'keyStores',
            'private_endpoint_id': 'privateEndpointId'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._time_created = None
        self._time_updated = None
        self._defined_tags = None
        self._freeform_tags = None
        self._system_tags = None
        self._type = None
        self._related_resource = None
        self._connection_string = None
        self._user_name = None
        self._user_password = None
        self._advanced_properties = None
        self._key_stores = None
        self._private_endpoint_id = None
        self._type = 'ORACLE_DATABASE'

    @property
    def related_resource(self):
        """
        Gets the related_resource of this DatabaseToolsConnectionOracleDatabase.

        :return: The related_resource of this DatabaseToolsConnectionOracleDatabase.
        :rtype: oci.database_tools.models.DatabaseToolsRelatedResource
        """
        return self._related_resource

    @related_resource.setter
    def related_resource(self, related_resource):
        """
        Sets the related_resource of this DatabaseToolsConnectionOracleDatabase.

        :param related_resource: The related_resource of this DatabaseToolsConnectionOracleDatabase.
        :type: oci.database_tools.models.DatabaseToolsRelatedResource
        """
        self._related_resource = related_resource

    @property
    def connection_string(self):
        """
        Gets the connection_string of this DatabaseToolsConnectionOracleDatabase.
        The connect descriptor or Easy Connect Naming method used to connect to the database.


        :return: The connection_string of this DatabaseToolsConnectionOracleDatabase.
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """
        Sets the connection_string of this DatabaseToolsConnectionOracleDatabase.
        The connect descriptor or Easy Connect Naming method used to connect to the database.


        :param connection_string: The connection_string of this DatabaseToolsConnectionOracleDatabase.
        :type: str
        """
        self._connection_string = connection_string

    @property
    def user_name(self):
        """
        Gets the user_name of this DatabaseToolsConnectionOracleDatabase.
        The database user name.


        :return: The user_name of this DatabaseToolsConnectionOracleDatabase.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this DatabaseToolsConnectionOracleDatabase.
        The database user name.


        :param user_name: The user_name of this DatabaseToolsConnectionOracleDatabase.
        :type: str
        """
        self._user_name = user_name

    @property
    def user_password(self):
        """
        Gets the user_password of this DatabaseToolsConnectionOracleDatabase.

        :return: The user_password of this DatabaseToolsConnectionOracleDatabase.
        :rtype: oci.database_tools.models.DatabaseToolsUserPassword
        """
        return self._user_password

    @user_password.setter
    def user_password(self, user_password):
        """
        Sets the user_password of this DatabaseToolsConnectionOracleDatabase.

        :param user_password: The user_password of this DatabaseToolsConnectionOracleDatabase.
        :type: oci.database_tools.models.DatabaseToolsUserPassword
        """
        self._user_password = user_password

    @property
    def advanced_properties(self):
        """
        Gets the advanced_properties of this DatabaseToolsConnectionOracleDatabase.
        The advanced connection properties key-value pair (for example, `oracle.net.ssl_server_dn_match`).


        :return: The advanced_properties of this DatabaseToolsConnectionOracleDatabase.
        :rtype: dict(str, str)
        """
        return self._advanced_properties

    @advanced_properties.setter
    def advanced_properties(self, advanced_properties):
        """
        Sets the advanced_properties of this DatabaseToolsConnectionOracleDatabase.
        The advanced connection properties key-value pair (for example, `oracle.net.ssl_server_dn_match`).


        :param advanced_properties: The advanced_properties of this DatabaseToolsConnectionOracleDatabase.
        :type: dict(str, str)
        """
        self._advanced_properties = advanced_properties

    @property
    def key_stores(self):
        """
        Gets the key_stores of this DatabaseToolsConnectionOracleDatabase.
        The Oracle wallet or Java Keystores containing trusted certificates for authenticating the server's public certificate and
        the client private key and associated certificates required for client authentication.


        :return: The key_stores of this DatabaseToolsConnectionOracleDatabase.
        :rtype: list[oci.database_tools.models.DatabaseToolsKeyStore]
        """
        return self._key_stores

    @key_stores.setter
    def key_stores(self, key_stores):
        """
        Sets the key_stores of this DatabaseToolsConnectionOracleDatabase.
        The Oracle wallet or Java Keystores containing trusted certificates for authenticating the server's public certificate and
        the client private key and associated certificates required for client authentication.


        :param key_stores: The key_stores of this DatabaseToolsConnectionOracleDatabase.
        :type: list[oci.database_tools.models.DatabaseToolsKeyStore]
        """
        self._key_stores = key_stores

    @property
    def private_endpoint_id(self):
        """
        Gets the private_endpoint_id of this DatabaseToolsConnectionOracleDatabase.
        The `OCID`__ of the Database Tools private endpoint used to access the database in the customer VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The private_endpoint_id of this DatabaseToolsConnectionOracleDatabase.
        :rtype: str
        """
        return self._private_endpoint_id

    @private_endpoint_id.setter
    def private_endpoint_id(self, private_endpoint_id):
        """
        Sets the private_endpoint_id of this DatabaseToolsConnectionOracleDatabase.
        The `OCID`__ of the Database Tools private endpoint used to access the database in the customer VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param private_endpoint_id: The private_endpoint_id of this DatabaseToolsConnectionOracleDatabase.
        :type: str
        """
        self._private_endpoint_id = private_endpoint_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JsonText(object):
    """
    The JSON type of the formatted text.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JsonText object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this JsonText.
        :type model_type: str

        :param config_values:
            The value to assign to the config_values property of this JsonText.
        :type config_values: oci.data_integration.models.ConfigValues

        """
        self.swagger_types = {
            'model_type': 'str',
            'config_values': 'ConfigValues'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'config_values': 'configValues'
        }

        self._model_type = None
        self._config_values = None

    @property
    def model_type(self):
        """
        Gets the model_type of this JsonText.
        The object type.


        :return: The model_type of this JsonText.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this JsonText.
        The object type.


        :param model_type: The model_type of this JsonText.
        :type: str
        """
        self._model_type = model_type

    @property
    def config_values(self):
        """
        Gets the config_values of this JsonText.

        :return: The config_values of this JsonText.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._config_values

    @config_values.setter
    def config_values(self, config_values):
        """
        Sets the config_values of this JsonText.

        :param config_values: The config_values of this JsonText.
        :type: oci.data_integration.models.ConfigValues
        """
        self._config_values = config_values

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateDrgDetails(object):
    """
    UpdateDrgDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateDrgDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateDrgDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param default_drg_route_tables:
            The value to assign to the default_drg_route_tables property of this UpdateDrgDetails.
        :type default_drg_route_tables: oci.vn_monitoring.models.DefaultDrgRouteTables

        :param display_name:
            The value to assign to the display_name property of this UpdateDrgDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateDrgDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'defined_tags': 'dict(str, dict(str, object))',
            'default_drg_route_tables': 'DefaultDrgRouteTables',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'defined_tags': 'definedTags',
            'default_drg_route_tables': 'defaultDrgRouteTables',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags'
        }

        self._defined_tags = None
        self._default_drg_route_tables = None
        self._display_name = None
        self._freeform_tags = None

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateDrgDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this UpdateDrgDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateDrgDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this UpdateDrgDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def default_drg_route_tables(self):
        """
        Gets the default_drg_route_tables of this UpdateDrgDetails.

        :return: The default_drg_route_tables of this UpdateDrgDetails.
        :rtype: oci.vn_monitoring.models.DefaultDrgRouteTables
        """
        return self._default_drg_route_tables

    @default_drg_route_tables.setter
    def default_drg_route_tables(self, default_drg_route_tables):
        """
        Sets the default_drg_route_tables of this UpdateDrgDetails.

        :param default_drg_route_tables: The default_drg_route_tables of this UpdateDrgDetails.
        :type: oci.vn_monitoring.models.DefaultDrgRouteTables
        """
        self._default_drg_route_tables = default_drg_route_tables

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateDrgDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateDrgDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateDrgDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateDrgDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateDrgDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this UpdateDrgDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateDrgDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this UpdateDrgDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
